==> pitivi_0.99.orig.tar.xz: pitivi-0.99/docs/The_people.md <==
# The people

This page is intended for new community members to know who to “go to”
for specific issues, as well as highlight the great work of our
contributors. You might have noticed that **some of us are connected at
all times** (using an IRC proxy such as
[bip](http://bip.milkypond.org)). Being connected does not necessarily
mean we are in front of the computer: if we have an Away status, you
need to be patient when asking questions as we might be temporarily
offline or on different timezones. We'll see your messages when we
reconnect using our IRC client.

Current maintainers:

-   Thibault Saunier: developer and
    current project maintainer, GSoC 2010 student
    -   Knows all the technical/architectural decisions
    -   Knows [GES](GES.md) inside-out
-   Alexandru “aleb” Băluț: Bug fixer, UI polisher, unittest juggler

Previous (co-)maintainers:

-   Jean-François “nekohayo” Fortin Tam: UI
    designer and occasional developer, tester, bug triager,
    documentation writer, webmaster.
    -   Knows about the vast majority of existing bugs (since he triages
        them)
    -   Elaborates the project's vision. Knows about design decisions,
        existing or missing features
    -   Offers guidance/mentoring to get acquainted with the project. In
        case of doubt, go to him!
-   Mathieu Duponchelle: hardcore bug
    fixer, GSoC 2011 and 2013 student
-   Edward “bilboed” Hervey: founder of the
    project. Knows GStreamer and GNonlin inside-out. Retired from the
    Pitivi project to focus on GStreamer.
-   Brandon “emdash” Lewis: features and UI work between 2008-2010.
-   Alessandro “twi\_” Decina: backend work between 2009-2010.

A lot of [Google Summer of Code students](Past_GSoCs.md) have
been contributed to Pitivi and GES.

Occasional community members and contributors include many other people.
See also <http://ohloh.net/p/pitivi/contributors> to get a historic
sense of scale.

-   Add your name here!

==> pitivi_2023.03.orig.tar.xz: pitivi-2023.03/docs/The_people.md <==
# The people

This page is intended for new community members to know who to “go to”
for specific issues, as well as highlight the great work of our
contributors. You might have noticed that **some of us are connected at
all times** (using an IRC proxy such as
[bip](http://bip.milkypond.org)). Being connected does not necessarily
mean we are in front of the computer: if we have an Away status, you
need to be patient when asking questions as we might be temporarily
offline or on different timezones. We'll see your messages when we
reconnect using our IRC client.

Current maintainers:

-   Thibault Saunier: developer and
    current project maintainer, GSoC 2010 student
    -   Knows all the technical/architectural decisions
    -   Knows [GES](GES.md) inside-out
-   Alexandru “aleb” Băluț: Bug fixer, UI polisher, unittest juggler

Previous (co-)maintainers:

-   Jean-François “nekohayo” Fortin Tam: UI
    designer and occasional developer, tester, bug triager,
    documentation writer, webmaster.
    -   Knows about the vast majority of existing bugs (since he triages
        them)
    -   Elaborates the project's vision. Knows about design decisions,
        existing or missing features
    -   Offers guidance/mentoring to get acquainted with the project. In
        case of doubt, go to him!
-   Mathieu Duponchelle: hardcore bug
    fixer, GSoC 2011 and 2013 student
-   Edward “bilboed” Hervey: founder of the
    project. Knows GStreamer and GNonlin inside-out. Retired from the
    Pitivi project to focus on GStreamer.
-   Brandon “emdash” Lewis: features and UI work between 2008-2010.
-   Alessandro “twi\_” Decina: backend work between 2009-2010.

A lot of [Google Summer of Code students](Past_GSoCs.md) have
been contributed to Pitivi and GES.

Occasional community members and contributors include many other people.
See also <https://www.openhub.net/p/pitivi/contributors> to get a historic
sense of scale.

-   Add your name here!
